betty.job module - Betty 0.4.0a4 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.job module

Provide utilities for running jobs concurrently.

class betty.job.Context

  Bases: `object`

  Define a job context.

  __init__()
  property cache: Cache[Any]

    Provide a cache for this job context.

    The cache is volatile and will be discarded once the job context is completed.

  property start: datetime

    When the job started.